/** 
 * ******************************************************************************
 * \file		buttons_drv.c
 * \date		:  15 . 2021 .
 * \version		0.0a
 * \author		
 * 
 * ----------------------------------------------------------------------------
 * \brief		 .
 * \details		   ,  .
 * <table>
 * <caption> Pinout </caption>
 * <tr><th>  PORTB         </th>
 * <tr><td>  PB13 <-> BTN1 </td>
 * <tr><td>  PB15 <-> BTN2 </td>
 * </table>
 *
 * ******************************************************************************
 */

#include "buttons_drv.h"

#include "stm32f10x.h"

/*
 * ============================================================================
 *   Declarations
 * ============================================================================
 */
/*---------------------------------------------------------
 * 	[Types]
 */
/*---------------------------------------------------------
 * 	[Structs, Enums]
 */
/*---------------------------------------------------------
 *  [Defines]
 */
#define BTN1_Pos	13
#define BTN2_Pos	15
/*---------------------------------------------------------
 *  [Macros]
 */
#define TH_FLT		2		//  

/**
 *    
 */
#define BTN_CHECK(in, _flt, _btn) 	\
		if((in) == 0)				\
		{							\
			if(_flt > TH_FLT)		\
				_btn = BTN_PRESS;	\
			else					\
				_flt++;				\
		}else						\
		{							\
			if(_flt > 0)			\
				_flt--;				\
			else 					\
				_btn = BTN_NO;		\
		}
/*---------------------------------------------------------
 *  [Private (static) variables]
 */
/*---------------------------------------------------------
 *  [Global variables]
 */
/*---------------------------------------------------------
 *  [External variables]
 */
/*---------------------------------------------------------
 *  [External function prototipes]
 */

/*
 * ============================================================================
 *
 *   Public (Global) functions
 *
 * ============================================================================
 */
/** \addtogroup LL_Drv
 *  @{ */

/** -------------------------------------------------------
 * \brief		  
 * \details		
 */
void Buttons_IO_Init(void)
{
	RCC->APB2ENR |= RCC_APB2ENR_IOPBEN;

	GPIOB->BSRR = (1 << 13) | (1 << 15);
	MODIFY_REG(GPIOB->CRH,
			GPIO_CRH_CNF13 | GPIO_CRH_CNF15,
			GPIO_CRH_CNF13_1 | GPIO_CRH_CNF15_1);

}//--------------------------------------------------------

/** -------------------------------------------------------
 * \brief    
 * \param[out] *st -   
 * \return    
 */
uint8_t ButtonsRead(btn_t *st)
{
	static int8_t filter[2] = {0, 0};
	static btn_t butt;
	uint16_t port = GPIOB->IDR;

	BTN_CHECK(port & (1 << BTN1_Pos), filter[0], butt.btn1)
	BTN_CHECK(port & (1 << BTN2_Pos), filter[1], butt.btn2)

	if((butt.btn1 != st->btn1)||(butt.btn2 != st->btn2))
	{
		st->btn1 = butt.btn1;
		st->btn2 = butt.btn2;
		return 1;
	}else
		return 0;

}//--------------------------------------------------------

/** @} */
/*==== END FILE =============================================================*/
