/** 
 * ******************************************************************************
 * \file		FreeRTOSConfig.h
 * \date		:  15 . 2021 .
 * \version		0.0a
 * \author		
 * 
 * ----------------------------------------------------------------------------
 * \brief		 FreeRTOS.
 * \details		
 *
 * ******************************************************************************
 */

#ifndef FREERTOSCONFIG_H_
#define FREERTOSCONFIG_H_

#include <stdint.h>
/*   */
#define configUSE_PREEMPTION                     1    ///<!  
#define configUSE_PORT_OPTIMISED_TASK_SELECTION  1    ///<!  
#define configUSE_TICKLESS_IDLE                  0    ///<!     Idle
#define configCPU_CLOCK_HZ                       8000000   ///<!   
#define configSYSTICK_CLOCK_HZ                   1000000   ///<!   SysTick
#define configTICK_RATE_HZ                       1000   ///<!   
#define configUSE_16_BIT_TICKS                   0    ///<!  16- 
#define configMAX_PRIORITIES                     5    ///<! .   
#define configMINIMAL_STACK_SIZE                 64   ///<! .   
#define configMAX_TASK_NAME_LEN                  16   ///<!   
#define configIDLE_SHOULD_YIELD                  1    ///<!
#define configUSE_TASK_NOTIFICATIONS             1    ///<!   
#define configTASK_NOTIFICATION_ARRAY_ENTRIES    3    ///<!   
#define configUSE_MUTEXES                        1    ///<!  
#define configUSE_RECURSIVE_MUTEXES              0    ///<!   
#define configUSE_COUNTING_SEMAPHORES            0    ///<!   
#define configQUEUE_REGISTRY_SIZE              	 10   ///<!  
#define configUSE_QUEUE_SETS                     0    ///<!   
#define configUSE_TIME_SLICING                   0
#define configUSE_NEWLIB_REENTRANT               0
#define configNUM_THREAD_LOCAL_STORAGE_POINTERS  5
#define configSTACK_DEPTH_TYPE                   uint16_t
#define configMESSAGE_BUFFER_LENGTH_TYPE         size_t

/*    */
#define configSUPPORT_STATIC_ALLOCATION             0    ///<!    
#define configSUPPORT_DYNAMIC_ALLOCATION            1    ///<!    
#define configTOTAL_HEAP_SIZE                       (3 * 1024)    ///<!   
#define configAPPLICATION_ALLOCATED_HEAP            0    ///<!    
#define configSTACK_ALLOCATION_FROM_SEPARATE_HEAP   0    ///<!     

/* - */
#define configUSE_IDLE_HOOK                         1    ///<!   Idle
#define configUSE_TICK_HOOK                         0    ///<!   Tick
#define configCHECK_FOR_STACK_OVERFLOW              0    ///<!   
#define configUSE_MALLOC_FAILED_HOOK                0    ///<!     
#define configUSE_DAEMON_TASK_STARTUP_HOOK          0    ///<!    

/*  - */
// void vApplicationIdleHook(void);
// void vApplicationTickHook(void);
// void vApplicationMallocFailedHook(void);
// void vApplicationDaemonTaskStartupHook(void);
// void vApplicationStackOverflowHook(TaskHandle_t xTask, signed char *pcTaskName);

/*      */
#define configGENERATE_RUN_TIME_STATS               0    ///<!   
#define configUSE_TRACE_FACILITY                    0    ///<! 
#define configUSE_STATS_FORMATTING_FUNCTIONS        0    ///<!   

/*  */
#define configUSE_CO_ROUTINES                       0    ///<!  
#define configMAX_CO_ROUTINE_PRIORITIES             0    ///<! . 

/*   */
#define configUSE_TIMERS                            1    ///<!   
#define configTIMER_TASK_PRIORITY                   3    ///<!  
#define configTIMER_QUEUE_LENGTH                    10   ///<!   
#define configTIMER_TASK_STACK_DEPTH                configMINIMAL_STACK_SIZE    ///<!   

/*    */
#ifdef __NVIC_PRIO_BITS
	#define configPRIO_BITS       __NVIC_PRIO_BITS
#else
	#define configPRIO_BITS       4        /* 15 priority levels */
#endif

/*     */
#define configLIBRARY_LOWEST_INTERRUPT_PRIORITY       15    ///<!     Cortex M
#define configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY  5     ///<!       API RTOS
#define configLIBRARY_MAX_APICALL_INTERRUPT_PRIORITY  5     ///<!       API RTOS

/* Interrupt nesting behaviour configuration. */
#define configKERNEL_INTERRUPT_PRIORITY           ( configLIBRARY_LOWEST_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )
#define configMAX_SYSCALL_INTERRUPT_PRIORITY      ( configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )
#define configMAX_API_CALL_INTERRUPT_PRIORITY     ( configLIBRARY_MAX_APICALL_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )

/* -  (Assert). */
#define configASSERT( x ) if( ( x ) == 0 ) { taskDISABLE_INTERRUPTS(); for( ;; ); }
//#define configASSERT( ( x ) ) if( ( x ) == 0 ) vAssertCalled( __FILE__, __LINE__ )


/*      */
#define INCLUDE_vTaskPrioritySet               1
#define INCLUDE_uxTaskPriorityGet              0
#define INCLUDE_vTaskDelete                    1
#define INCLUDE_vTaskSuspend                   1
#define INCLUDE_xResumeFromISR                 1
#define INCLUDE_vTaskDelayUntil                1
#define INCLUDE_vTaskDelay                     1
#define INCLUDE_xTaskGetSchedulerState         0
#define INCLUDE_xTaskGetCurrentTaskHandle      0
#define INCLUDE_uxTaskGetStackHighWaterMark    0
#define INCLUDE_xTaskGetIdleTaskHandle         0
#define INCLUDE_eTaskGetState                  0
#define INCLUDE_xEventGroupSetBitFromISR       0
#define INCLUDE_xTimerPendFunctionCall         0
#define INCLUDE_xTaskAbortDelay                0
#define INCLUDE_xTaskGetHandle                 0
#define INCLUDE_xTaskResumeFromISR             1

/*    */
#define vPortSVCHandler                       SVC_Handler
#define xPortPendSVHandler                    PendSV_Handler
#define xPortSysTickHandler                   SysTick_Handler
//=============================================================================
#endif /* FREERTOSCONFIG_H_ */
