/** 
 * ******************************************************************************
 * \file		system_stm32f10x.c
 * \date		:  11 . 2019 .
 * \version		0.0a
 * \author		
 * 
 * ----------------------------------------------------------------------------
 * \brief		  MCU.
 *
 * ******************************************************************************
 */

/*--- [MCU header] ----------------------*/
#include "stm32f10x.h"

/*--- [Drivers] -------------------------*/


/*
 * ============================================================================
 *   Declarations
 * ============================================================================
 */
/*---------------------------------------------------------
 * 	[Types]
 */
/*---------------------------------------------------------
 * 	[Structs, Enums]
 */
/*---------------------------------------------------------
 *  [Defines]
 */
//#define VECT_TAB_SRAM			///<     SRAM
#define VECT_TAB_OFFSET  0x0 	///<    ( 0x200)

/*---------------------------------------------------------
 *  [Macros]
 */
/*---------------------------------------------------------
 *  [Private (static) variables]
 */
/*---------------------------------------------------------
 *  [Global variables]
 */
/** \addtogroup SysLayer
  * @{ */
uint32_t SystemCoreClock = HSI_VALUE;     /*!< System Clock Frequency (Core Clock) */
/** @} */

///  
__I uint8_t AHBPrescTable[16] = {0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 4, 6, 7, 8, 9};


/*---------------------------------------------------------
 *  [External variables]
 */
/*---------------------------------------------------------
 *  [External function prototipes]
 */

/*
 * ============================================================================
 *
 *   Private (Static) functions
 *
 * ============================================================================
 */

/** -------------------------------------------------------
 * \brief		
 * \details		
 */
static void SetSysClock(void)
{

}//--------------------------------------------------------


/* ____________________________________________________________________________
 * ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * ____________________________________________________________________________
 */

/*
 * ============================================================================
 *
 *   Global (Public) functions
 *
 * ============================================================================
 */
/** \addtogroup SysLayer
 *  @{ */

/** -------------------------------------------------------
 * \brief	  MCU.
 * \details	 Flash,  ,  .
 * \note   	      .
 */
void SystemInit(void)
{
	SetSysClock();



#ifdef VECT_TAB_SRAM
	SCB->VTOR = SRAM_BASE | VECT_TAB_OFFSET; /*    SRAM. */
#else
	SCB->VTOR = FLASH_BASE | VECT_TAB_OFFSET; /*    FLASH. */
#endif
}//--------------------------------------------------------


/**--------------------------------------------------------
 * \brief	  SystemCoreClock    
 * 			  .
 *
 * \note	      (HCLK),   
 * 			     SystemCoreClock.   
 * 			,    ,  .
 *
 * \note	-   -  ,    . 
 * 			        :
 * 			  +   HSI, SystemCoreClock = HSI_VALUE(*)
 * 			  +   HSE, SystemCoreClock = HSE_VALUE(**)
 * 			  +   PLL, SystemCoreClock = HSE_VALUE(**)  HSI_VALUE(*),
 * 			      . PLL.
 *
 * \warning	(*)  HSI_VALUE    stm32f1xx.h (  8 MHz),
 * 				         .
 *
 * \warning	(**) HSE_VALUE    stm32f1xx.h (  8  25 MHz),
 * 			         ,  
 * 			      .
 *
 * \attention	       
 * 				   HSE.
 */
void SystemCoreClockUpdate(void)
{
	uint32_t tmp = 0, pllmull = 0, pllsource = 0;

#ifdef  STM32F10X_CL
	uint32_t prediv1source = 0, prediv1factor = 0, prediv2factor = 0, pll2mull = 0;
#endif /* STM32F10X_CL */

#if defined (STM32F10X_LD_VL) || defined (STM32F10X_MD_VL) || (defined STM32F10X_HD_VL)
	uint32_t prediv1factor = 0;
#endif /* STM32F10X_LD_VL or STM32F10X_MD_VL or STM32F10X_HD_VL */

	/* Get SYSCLK source -------------------------------------------------------*/
	tmp = RCC->CFGR & RCC_CFGR_SWS;

	switch (tmp)
	{
	case 0x00:  /* HSI used as system clock */
		SystemCoreClock = HSI_VALUE;
		break;
	case 0x04:  /* HSE used as system clock */
		SystemCoreClock = HSE_VALUE;
		break;
	case 0x08:  /* PLL used as system clock */

		/* Get PLL clock source and multiplication factor ----------------------*/
		pllmull = RCC->CFGR & RCC_CFGR_PLLMULL;
		pllsource = RCC->CFGR & RCC_CFGR_PLLSRC;

#ifndef STM32F10X_CL
		pllmull = ( pllmull >> 18) + 2;

		if (pllsource == 0x00)
		{
			/* HSI oscillator clock divided by 2 selected as PLL clock entry */
			SystemCoreClock = (HSI_VALUE >> 1) * pllmull;
		}
		else
		{
#if defined (STM32F10X_LD_VL) || defined (STM32F10X_MD_VL) || (defined STM32F10X_HD_VL)
			prediv1factor = (RCC->CFGR2 & RCC_CFGR2_PREDIV1) + 1;
			/* HSE oscillator clock selected as PREDIV1 clock entry */
			SystemCoreClock = (HSE_VALUE / prediv1factor) * pllmull;
#else
			/* HSE selected as PLL clock entry */
			if ((RCC->CFGR & RCC_CFGR_PLLXTPRE) != (uint32_t)RESET)
			{/* HSE oscillator clock divided by 2 */
				SystemCoreClock = (HSE_VALUE >> 1) * pllmull;
			}
			else
			{
				SystemCoreClock = HSE_VALUE * pllmull;
			}
#endif
		}
#else
		pllmull = pllmull >> 18;

		if (pllmull != 0x0D)
		{
			pllmull += 2;
		}
		else
		{ /* PLL multiplication factor = PLL input clock * 6.5 */
			pllmull = 13 / 2;
		}

		if (pllsource == 0x00)
		{
			/* HSI oscillator clock divided by 2 selected as PLL clock entry */
			SystemCoreClock = (HSI_VALUE >> 1) * pllmull;
		}
		else
		{/* PREDIV1 selected as PLL clock entry */

			/* Get PREDIV1 clock source and division factor */
			prediv1source = RCC->CFGR2 & RCC_CFGR2_PREDIV1SRC;
			prediv1factor = (RCC->CFGR2 & RCC_CFGR2_PREDIV1) + 1;

			if (prediv1source == 0)
			{
				/* HSE oscillator clock selected as PREDIV1 clock entry */
				SystemCoreClock = (HSE_VALUE / prediv1factor) * pllmull;
			}
			else
			{/* PLL2 clock selected as PREDIV1 clock entry */

				/* Get PREDIV2 division factor and PLL2 multiplication factor */
				prediv2factor = ((RCC->CFGR2 & RCC_CFGR2_PREDIV2) >> 4) + 1;
				pll2mull = ((RCC->CFGR2 & RCC_CFGR2_PLL2MUL) >> 8 ) + 2;
				SystemCoreClock = (((HSE_VALUE / prediv2factor) * pll2mull) / prediv1factor) * pllmull;
			}
		}
#endif /* STM32F10X_CL */
		break;

	default:
		SystemCoreClock = HSI_VALUE;
		break;
	}

	/* Compute HCLK clock frequency ----------------*/
	/* Get HCLK prescaler */
	tmp = AHBPrescTable[((RCC->CFGR & RCC_CFGR_HPRE) >> 4)];
	/* HCLK clock frequency */
	SystemCoreClock >>= tmp;
}//-------------------------------------------------------


/** @} */
/*==== END FILE =============================================================*/
